@@ -13,6 +13,7 @@ import colormath
 from log import safe_print
 from options import debug, verbose
 from util_io import GzipFileProper, StringIOu as StringIO
+from util_str import safe_unicode
 
 
 def get_device_value_labels(color_rep=None):
@@ -243,7 +244,7 @@ class CGATS(dict):
 		"""
 		
 		self.normalize_fields = normalize_fields
-		self.file_identifier = file_identifier
+		self.file_identifier = file_identifier.strip()
 		self.emit_keywords = emit_keywords
 		self.root = self
 		self._keys = []
@@ -433,8 +434,14 @@ class CGATS(dict):
 				colorants.append(self.queryi1(query))
 			return colorants
 
-	def get_descriptor(self):
-		""" Return descriptor """
+	def get_descriptor(self, localized=True):
+		"""
+		Return CGATS description as unicode, based on metadata
+		
+		If 'localized' is True (default), include localized technology
+		description for CCSS files.
+		
+		"""
 		desc = self.queryv1("DESCRIPTOR")
 		is_ccss = self.get(0, self).type == "CCSS"
 		if not desc or desc == "Not specified" or is_ccss:
@@ -452,13 +459,23 @@ class CGATS(dict):
 						display = desc
 					else:
 						display = self.queryv1("DISPLAY")
-					if display:
+					if localized:
 						import localization as lang
-						tech = lang.getstr("display.tech." + tech, default=tech)
+						tech = safe_unicode(tech, "UTF-8")
+						tech = lang.getstr(u"display.tech." + tech, default=tech)
+						if display:
+							# Localized tech will be unicode always, need to
+							# make sure display is as well
+							display = safe_unicode(display, "UTF-8")
+					if display:
 						tech += " (%s)" % display
 				desc = tech
 		if not desc and self.filename:
-			desc = os.path.splitext(os.path.basename(self.filename))[0]
+			# Filesystem encoding can be different than UTF-8 (depending on
+			# platform), by default safe_unicode will use FS enc
+			desc = safe_unicode(os.path.splitext(os.path.basename(self.filename))[0])
+		else:
+			desc = safe_unicode(desc or "", "UTF-8")
 		return desc
 
 	def __setattr__(self, name, value):
@@ -1883,7 +1900,7 @@ Transform {
 		"""
 		n = 0
 		for dataset in self.query("DATA").itervalues():
-			if not dataset.has_cie():
+			if not dataset.get_cie_data_format():
 				continue
 			if not whitepoint_source:
 				whitepoint_source = dataset.get_white_cie("XYZ")
@@ -2012,7 +2029,7 @@ Transform {
 		Get the 'white' from the CIE values (if any).
 		
 		"""
-		data_format = self.has_cie()
+		data_format = self.get_cie_data_format()
 		if data_format:
 			if "RGB_R" in data_format.values():
 				white = {"RGB_R": 100, "RGB_G": 100, "RGB_B": 100}
@@ -2063,7 +2080,7 @@ Transform {
 												 white["XYZ_Z"])
 				return white
 	
-	def has_cie(self):
+	def get_cie_data_format(self):
 		"""
 		Check if DATA_FORMAT defines any CIE XYZ or LAB columns.
 		
@@ -2078,7 +2095,7 @@ Transform {
 			if len(cie.values()) in (0, 3):
 				for ch in ("X", "Y", "Z"):
 					cie[ch] = "XYZ_%s" % ch in data_format.values()
-				if len(filter(lambda v: v is not None,
+				if len(filter(lambda v: v is not False,
 							  cie.itervalues())) in (3, 6):
 					return data_format
 	
